@@ -7,7 +7,7 @@ use Result::Trait ();
 package Result::OkList;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use parent qw( Result::Ok );
 
@@ -44,7 +44,7 @@ for objects of this class.
 =head1 BUGS
 
 Please report any bugs to
-<https://github.com/tobyink/p5-results/issues>.
+L<https://github.com/tobyink/p5-results/issues>.
 
 =head1 SEE ALSO
 
