@@ -11,8 +11,7 @@ use warnings;
 =head1 NAME
 
 Result::Trait - the trait which all Result objects implement
-
-=head1 SYNOPSIS
+head1 SYNOPSIS
 
   use results;
   
@@ -49,7 +48,7 @@ require results;
 package Result::Trait;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use Role::Tiny;
 
@@ -792,7 +791,7 @@ If C<< get_config() >> returns an ok Result containing a hashref, then:
 
   use Types::Common qw( HashRef );
   
-  my $config = get_config->type_or( HashRef, {} )->unwrap();
+  my $config = get_config->type_or( {}, HashRef )->unwrap();
 
 =cut
 
@@ -1009,7 +1008,7 @@ the default implementations are not the fastest.
 =head1 BUGS
 
 Please report any bugs to
-<https://github.com/tobyink/p5-results/issues>.
+L<https://github.com/tobyink/p5-results/issues>.
 
 =head1 SEE ALSO
 
