@@ -8,7 +8,7 @@ use Scalar::Util ();
 package results;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use Exporter::Shiny qw( err is_result ok ok_list );
 our @EXPORT = qw( err ok );
@@ -434,7 +434,7 @@ L<results::exceptions> also supports lexical exports:
 =head1 BUGS
 
 Please report any bugs to
-<https://github.com/tobyink/p5-results/issues>.
+L<https://github.com/tobyink/p5-results/issues>.
 
 =head1 SEE ALSO
 
