@@ -5,7 +5,7 @@ use warnings;
 package results::exceptions;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.004';
+our $VERSION   = '0.005';
 
 use results ();
 use B ();
@@ -202,7 +202,7 @@ versions of Perl.
 =head1 BUGS
 
 Please report any bugs to
-<https://github.com/tobyink/p5-results/issues>.
+L<https://github.com/tobyink/p5-results/issues>.
 
 =head1 SEE ALSO
 
